- Inheritance
-
- Implemented types
-
- Implementers
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
exec(String command, {dynamic external = false, String? path, Shell? shell})
→ dynamic
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
runExternalCommand(dynamic command, dynamic path)
→ dynamic
-
Helps to create temporary script to run on the system
-
toString()
→ String
-
A string representation of this object.
inherited